@@ -14,6 +14,7 @@ from collections import namedtuple
 from glob import glob
 from subprocess import check_output
 from datetime import datetime
+from time import sleep
 
 from nipype.utils.filemanip import which
 
@@ -46,7 +47,8 @@ seqinfo_fields = [
     'patient_sex',           # 23
     'date',                  # 24
     'series_uid',            # 25
- ]
+    'time',                  # 26
+]
 
 SeqInfo = namedtuple('SeqInfo', seqinfo_fields)
 
@@ -146,39 +148,40 @@ def write_config(outfile, info):
         fp.writelines(PrettyPrinter().pformat(info))
 
 
-def _canonical_dumps(json_obj, **kwargs):
-    """ Dump `json_obj` to string, allowing for Python newline bug
-
-    Runs ``json.dumps(json_obj, \*\*kwargs), then removes trailing whitespaces
-    added when doing indent in some Python versions. See
-    https://bugs.python.org/issue16333. Bug seems to be fixed in 3.4, for now
-    fixing manually not only for aestetics but also to guarantee the same
-    result across versions of Python.
-    """
-    out = json.dumps(json_obj, **kwargs)
-    if 'indent' in kwargs:
-        out = out.replace(' \n', '\n')
-    return out
-
-
-def load_json(filename):
+def load_json(filename, retry=0):
     """Load data from a json file
 
     Parameters
     ----------
     filename : str
         Filename to load data from.
+    retry: int, optional
+        Number of times to retry opening/loading the file in case of
+        failure.  Code will sleep for 0.1 seconds between retries.
+        Could be used in code which is not sensitive to order effects
+        (e.g. like populating bids templates where the last one to
+        do it, would make sure it would be the correct/final state).
 
     Returns
     -------
     data : dict
     """
-    try:
-        with open(filename, 'r') as fp:
-            data = json.load(fp)
-    except JSONDecodeError:
-        lgr.error("{fname} is not a valid json file".format(fname=filename))
-        raise
+    assert retry >= 0
+    for i in range(retry + 1):  # >= 10 sec wait
+        try:
+            try:
+                with open(filename, 'r') as fp:
+                    data = json.load(fp)
+                    break
+            except JSONDecodeError:
+                lgr.error("{fname} is not a valid json file".format(fname=filename))
+                raise
+        except (JSONDecodeError, FileNotFoundError) as exc:
+            if i >= retry:
+                raise
+            lgr.warning("Caught %s. Will retry again", exc)
+            sleep(0.1)
+            continue
 
     return data
     
@@ -219,19 +222,25 @@ def save_json(filename, data, indent=2, sort_keys=True, pretty=False):
                 % (str(exc), filename)
             )
     if not pretty:
-        j = _canonical_dumps(data, **dumps_kw)
+        j = json_dumps(data, **dumps_kw)
     assert j is not None  # one way or another it should have been set to a str
     with open(filename, 'w') as fp:
         fp.write(j)
 
 
+def json_dumps(json_obj, indent=2, sort_keys=True):
+    """Unified (default indent and sort_keys) invocation of json.dumps
+    """
+    return json.dumps(json_obj, indent=indent, sort_keys=sort_keys)
+
+
 def json_dumps_pretty(j, indent=2, sort_keys=True):
     """Given a json structure, pretty print it by colliding numeric arrays
     into a line.
 
     If resultant structure differs from original -- throws exception
     """
-    js = _canonical_dumps(j, indent=indent, sort_keys=sort_keys)
+    js = json_dumps(j, indent=indent, sort_keys=sort_keys)
     # trim away \n and spaces between entries of numbers
     js_ = re.sub(
         '[\n ]+("?[-+.0-9e]+"?,?) *\n(?= *"?[-+.0-9e]+"?)', r' \1',
